pub struct IVCStatefulProver<'a, FC: FCircuit<Field = I::Field>, I: IVC> {
pub i: usize,
pub initial_state: FC::State,
pub current_state: FC::State,
pub current_proof: I::Proof<FC>,
/* private fields */
}Expand description
IVCStatefulProver is a convenience struct that implements a stateful IVC
prover who maintains running state across iterations, so that the user does
not need to manually track and pass in the current state and proof at each
step.
Fields
i: usizeIVCStatefulProver::i is the number of steps proved so far.
initial_state: FC::StateIVCStatefulProver::initial_state is the initial state of iterative
step circuit executions.
current_state: FC::StateIVCStatefulProver::current_state is the current state of iterative
step circuit executions, reached after Self::i steps.
current_proof: I::Proof<FC>IVCStatefulProver::current_proof is the current proof attesting that
Self::current_state is indeed derived from Self::initial_state
after executing the step circuit iteratively for Self::i steps.
Implementations
Sourceimpl<'a, FC: FCircuit<Field = I::Field>, I: IVC> IVCStatefulProver<'a, FC, I>
impl<'a, FC: FCircuit<Field = I::Field>, I: IVC> IVCStatefulProver<'a, FC, I>
Sourcepub fn new(
pk: &'a I::ProverKey<FC>,
step_circuit: &'a FC,
initial_state: FC::State,
) -> Result<Self, Error>
pub fn new( pk: &'a I::ProverKey<FC>, step_circuit: &'a FC, initial_state: FC::State, ) -> Result<Self, Error>
IVCStatefulProver::new creates a new stateful IVC prover with the
given prover key pk, step circuit step_circuit, and initial state
initial_state.
Sourcepub fn prove_step(
&mut self,
external_inputs: FC::ExternalInputs,
rng: impl RngCore,
) -> Result<FC::ExternalOutputs, Error>
pub fn prove_step( &mut self, external_inputs: FC::ExternalInputs, rng: impl RngCore, ) -> Result<FC::ExternalOutputs, Error>
IVCStatefulProver::prove_step performs one step of proving, updating
the internal state and proof, and returning the external outputs.